@@ -40,9 +40,22 @@ You can contact the author at :
 // If you know your target CPU supports unaligned memory access, you want to force this option manually to improve performance.
 // You can also enable this parameter if you know your input data will always be aligned (boundaries of 4, for U32).
 #if defined(__ARM_FEATURE_UNALIGNED) || defined(__i386) || defined(_M_IX86) || defined(__x86_64__) || defined(_M_X64)
-// panto: -fsanitize fails with this so disable if compiling with it enabled
-#  if !defined(__SANITIZE_ADDRESS__)
-#     define XXH_USE_UNALIGNED_ACCESS 1
+#  define XXH_USE_UNALIGNED_ACCESS 1
+#endif
+
+// panto: disable unaligned access when running with asan
+#if defined(XXH_USE_UNALIGNED_ACCESS)
+#  if defined(__has_feature)
+#    if __has_feature(address_sanitizer)
+#      undef XXH_USE_UNALIGNED_ACCESS
+#    endif
+#  endif
+#endif
+
+// fallback for old GCC versions
+#if defined(XXH_USE_UNALIGNED_ACCESS)
+#  if defined(__SANITIZE_ADDRESS__)
+#    undef XXH_USE_UNALIGNED_ACCESS
 #  endif
 #endif
 
